@@ -409,20 +409,6 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
   /* next row */
   row++;
 
-  button = gtk_check_button_new_with_mnemonic (_("Sort _folders before files"));
-  g_object_bind_property (G_OBJECT (dialog->preferences),
-                          "misc-folders-first",
-                          G_OBJECT (button),
-                          "active",
-                          G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
-  gtk_widget_set_tooltip_text (button, _("Select this option to list folders before files when you sort a folder."));
-  gtk_widget_set_hexpand (button, TRUE);
-  gtk_grid_attach (GTK_GRID (grid), button, 0, row, 1, 1);
-  gtk_widget_show (button);
-
-  /* next row */
-  row++;
-
   button = gtk_check_button_new_with_mnemonic (_("Show file size in binary format"));
   g_object_bind_property (G_OBJECT (dialog->preferences),
                           "misc-file-size-binary",
