@@ -2594,10 +2594,26 @@ thunar_tree_view_model_sort (ThunarTreeViewModel *model)
 static void
 _thunar_tree_view_model_folder_destroy (Node *node)
 {
-  /* if a subdir get's destroyed it's handled internally but if the current_folder
-   * get's destroyed then we simply set_folder to NULL & cleanup things */
+  /* if a subdir gets destroyed, it's handled internally, but if the current_folder
+   * gets destroyed, then we simply set_folder to NULL & cleanup things */
   if (node->parent == NULL)
-    thunar_tree_view_model_set_folder (THUNAR_STANDARD_VIEW_MODEL (node->model), NULL, NULL);
+    {
+      if (node->n_children > 0)
+        {
+          /* set_folder func does not emit row-deleted signal, but instead relies on
+           * ThunarStandardView to disconnect & reconnect the view to quickly update
+           * changes in current_directory. */
+          GList *keys = g_hash_table_get_keys (node->set);
+
+          for (GList *lp = keys; lp != NULL; lp = lp->next)
+            thunar_tree_view_model_dir_remove_file (node, THUNAR_FILE (lp->data));
+
+          g_list_free (keys);
+        }
+
+      /* reset the model */
+      thunar_tree_view_model_set_folder (THUNAR_STANDARD_VIEW_MODEL (node->model), NULL, NULL);
+    }
 }
 
 
@@ -2608,26 +2624,10 @@ _thunar_tree_view_model_folder_error (Node         *node,
 {
   _thunar_return_if_fail (error != NULL);
 
-  if (node->n_children > 0)
-    {
-      if (node->parent == NULL)
-        {
-          /* set_folder func does not emit row-deleted signal instead relies
-           * on ThunarStandardView to disconnect & reconnect the view quickly update
-           * changes in current_directory. */
-          GList *keys = g_hash_table_get_keys (node->set);
-
-          for (GList *lp = keys; lp != NULL; lp = lp->next)
-            thunar_tree_view_model_dir_remove_file (node, THUNAR_FILE (lp->data));
-
-          g_list_free (keys);
-
-          /* reset the model if error is with the current directory */
-          thunar_tree_view_model_set_folder (THUNAR_STANDARD_VIEW_MODEL (node->model), NULL, NULL);
-        }
-      else
-        thunar_tree_view_model_dir_remove_file (node->parent, node->file);
-    }
+  if (node->parent == NULL)
+    _thunar_tree_view_model_folder_destroy (node);
+  else
+    thunar_tree_view_model_dir_remove_file (node->parent, node->file);
 
   /* forward the error signal */
   g_signal_emit_by_name (G_OBJECT (node->model), "error", error);
