@@ -563,8 +563,8 @@ thunar_util_parse_parent (gpointer    parent,
     }
   else if (GDK_IS_SCREEN (parent))
     {
-      /* yep, that's a screen */
-      screen = GDK_SCREEN (parent);
+      /* A specific screen was requested. Just return it, without filling 'window_return' */
+      return GDK_SCREEN (parent);
     }
   else
     {
@@ -836,7 +836,12 @@ thunar_util_next_new_file_name_raw (GList                 *file_list,
 const char *
 thunar_util_get_search_prefix (void)
 {
-  return _("Search: ");
+  static gchar *prefix = NULL;
+
+  if (prefix == NULL)
+    prefix = g_strconcat (_("Search:"), " ", NULL);
+
+  return prefix;
 }
 
 
